# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/transport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.monitoring import monitoring_pb2 as stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/transport.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.stellarstation.api.v1B\016TransportProtoP\001Z2github.com/infostellarinc/go-stellarstation/api/v1'),
  serialized_pb=_b('\n%stellarstation/api/v1/transport.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31stellarstation/api/v1/monitoring/monitoring.proto\"\xfa\x01\n\tTelemetry\x12/\n\x07\x66raming\x18\x01 \x01(\x0e\x32\x1e.stellarstation.api.v1.Framing\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x1d\n\x15\x64ownlink_frequency_hz\x18\x03 \x01(\x04\x12<\n\x18time_first_byte_received\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17time_last_byte_received\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rame_header\x18\x06 \x01(\x0c\"\xf0\x01\n\x0bStreamEvent\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12W\n\x0c\x63ommand_sent\x18\x02 \x01(\x0b\x32?.stellarstation.api.v1.StreamEvent.CommandSentFromGroundStationH\x00\x12K\n\x15plan_monitoring_event\x18\x03 \x01(\x0b\x32*.stellarstation.api.v1.PlanMonitoringEventH\x00\x1a\x1e\n\x1c\x43ommandSentFromGroundStationB\x07\n\x05\x45vent\"\xc0\x02\n\x13PlanMonitoringEvent\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x64\n\x1cground_station_configuration\x18\x02 \x01(\x0b\x32<.stellarstation.api.v1.monitoring.GroundStationConfigurationH\x00\x12T\n\x14ground_station_state\x18\x03 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationStateH\x00\x12T\n\x14ground_station_event\x18\x04 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationEventH\x00\x42\x06\n\x04Info*l\n\x07\x46raming\x12\r\n\tBITSTREAM\x10\x00\x12\x08\n\x04\x41X25\x10\x01\x12\x06\n\x02IQ\x10\x02\x12\r\n\tIMAGE_PNG\x10\x03\x12\x0e\n\nIMAGE_JPEG\x10\x04\x12\x12\n\x0e\x46REE_TEXT_UTF8\x10\x05\x12\r\n\tWATERFALL\x10\x06\x42\x61\n\x19\x63om.stellarstation.api.v1B\x0eTransportProtoP\x01Z2github.com/infostellarinc/go-stellarstation/api/v1b\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2.DESCRIPTOR,])

_FRAMING = _descriptor.EnumDescriptor(
  name='Framing',
  full_name='stellarstation.api.v1.Framing',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BITSTREAM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AX25', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IQ', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_PNG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_JPEG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FREE_TEXT_UTF8', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WATERFALL', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=967,
  serialized_end=1075,
)
_sym_db.RegisterEnumDescriptor(_FRAMING)

Framing = enum_type_wrapper.EnumTypeWrapper(_FRAMING)
BITSTREAM = 0
AX25 = 1
IQ = 2
IMAGE_PNG = 3
IMAGE_JPEG = 4
FREE_TEXT_UTF8 = 5
WATERFALL = 6



_TELEMETRY = _descriptor.Descriptor(
  name='Telemetry',
  full_name='stellarstation.api.v1.Telemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framing', full_name='stellarstation.api.v1.Telemetry.framing', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.Telemetry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_frequency_hz', full_name='stellarstation.api.v1.Telemetry.downlink_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_first_byte_received', full_name='stellarstation.api.v1.Telemetry.time_first_byte_received', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_last_byte_received', full_name='stellarstation.api.v1.Telemetry.time_last_byte_received', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_header', full_name='stellarstation.api.v1.Telemetry.frame_header', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=399,
)


_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION = _descriptor.Descriptor(
  name='CommandSentFromGroundStation',
  full_name='stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=633,
)

_STREAMEVENT = _descriptor.Descriptor(
  name='StreamEvent',
  full_name='stellarstation.api.v1.StreamEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.StreamEvent.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_sent', full_name='stellarstation.api.v1.StreamEvent.command_sent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan_monitoring_event', full_name='stellarstation.api.v1.StreamEvent.plan_monitoring_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='stellarstation.api.v1.StreamEvent.Event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=402,
  serialized_end=642,
)


_PLANMONITORINGEVENT = _descriptor.Descriptor(
  name='PlanMonitoringEvent',
  full_name='stellarstation.api.v1.PlanMonitoringEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.PlanMonitoringEvent.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_configuration', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_state', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_event', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Info', full_name='stellarstation.api.v1.PlanMonitoringEvent.Info',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=645,
  serialized_end=965,
)

_TELEMETRY.fields_by_name['framing'].enum_type = _FRAMING
_TELEMETRY.fields_by_name['time_first_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRY.fields_by_name['time_last_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION.containing_type = _STREAMEVENT
_STREAMEVENT.fields_by_name['command_sent'].message_type = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION
_STREAMEVENT.fields_by_name['plan_monitoring_event'].message_type = _PLANMONITORINGEVENT
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['command_sent'])
_STREAMEVENT.fields_by_name['command_sent'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['plan_monitoring_event'])
_STREAMEVENT.fields_by_name['plan_monitoring_event'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONCONFIGURATION
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONSTATE
_PLANMONITORINGEVENT.fields_by_name['ground_station_event'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONEVENT
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_state'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_event'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_event'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
DESCRIPTOR.message_types_by_name['Telemetry'] = _TELEMETRY
DESCRIPTOR.message_types_by_name['StreamEvent'] = _STREAMEVENT
DESCRIPTOR.message_types_by_name['PlanMonitoringEvent'] = _PLANMONITORINGEVENT
DESCRIPTOR.enum_types_by_name['Framing'] = _FRAMING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Telemetry = _reflection.GeneratedProtocolMessageType('Telemetry', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRY,
  __module__ = 'stellarstation.api.v1.transport_pb2'
  ,
  __doc__ = """A chunk or frame of telemetry data that has been received from a
  satellite.
  
  
  Attributes:
      framing:
          The framing of this telemetry data. If ``RAW``, this telemetry
          will be an arbitrarily sized chunk of the bitstream.
      data:
          The payload of this telemetry.
      downlink_frequency_hz:
          The actual downlink frequency, in Hz, used when receiving
          ``data``, including adjustments for doppler shift.
      time_first_byte_received:
          Timestamp when the first byte of ``data`` was received.
      time_last_byte_received:
          Timestamp when the last byte of ``data`` was received.
      frame_header:
          The binary header of the telemetry frame, if ``framing`` is
          not ``RAW``.  -  AX25 - This is either Address + Control, or
          Address + Control + PID.    The checksum is not returned.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Telemetry)
  ))
_sym_db.RegisterMessage(Telemetry)

StreamEvent = _reflection.GeneratedProtocolMessageType('StreamEvent', (_message.Message,), dict(

  CommandSentFromGroundStation = _reflection.GeneratedProtocolMessageType('CommandSentFromGroundStation', (_message.Message,), dict(
    DESCRIPTOR = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION,
    __module__ = 'stellarstation.api.v1.transport_pb2'
    ,
    __doc__ = """An event indicating the commands in the request were sent by the ground
    station through its radio.
    
    Empty, may be extended in the future.
    """,
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation)
    ))
  ,
  DESCRIPTOR = _STREAMEVENT,
  __module__ = 'stellarstation.api.v1.transport_pb2'
  ,
  __doc__ = """A stream event payload.
  
  
  Attributes:
      request_id:
          The ID of the request this event corresponds to, copied from
          ``SatelliteStreamRequest.request_id`` when present. If the
          event doesn’t correspond to a request, this is always empty.
      command_sent:
          An event indicating the commands in the request were sent by
          the ground station through its radio.
      plan_monitoring_event:
          An event with monitoring information for a particular executed
          plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent)
  ))
_sym_db.RegisterMessage(StreamEvent)
_sym_db.RegisterMessage(StreamEvent.CommandSentFromGroundStation)

PlanMonitoringEvent = _reflection.GeneratedProtocolMessageType('PlanMonitoringEvent', (_message.Message,), dict(
  DESCRIPTOR = _PLANMONITORINGEVENT,
  __module__ = 'stellarstation.api.v1.transport_pb2'
  ,
  __doc__ = """A monitoring event that occurred during the execution of the plan.
  Information about the current configuration of the ground station and
  state of components is returned to provide information that can help to
  troubleshoot issues with the plan.
  
  
  Attributes:
      plan_id:
          The ID of the plan being monitored.
      ground_station_configuration:
          Information about the current configuration of the ground
          station when beginning to execute a plan. This will only be
          returned once at the beginning of execution. Information that
          is provided by the ground station executing the plan will be
          returned - any fields that are not supported by the ground
          station will be left unfilled.
      ground_station_state:
          Information about the current state of the ground station
          while executing a plan. This will be returned periodically
          during execution of the plan. Information that is provided by
          the ground station executing the plan will be returned - any
          fields that are not supported by the ground station will be
          left unfilled.
      ground_station_event:
          Information about events generated by the ground station while
          executing a plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMonitoringEvent)
  ))
_sym_db.RegisterMessage(PlanMonitoringEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/groundstation/groundstation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2
from stellarstation.api.v1 import transport_pb2 as stellarstation_dot_api_dot_v1_dot_transport__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/groundstation/groundstation.proto',
  package='stellarstation.api.v1.groundstation',
  syntax='proto3',
  serialized_options=_b('\n\'com.stellarstation.api.v1.groundstationB\022GroundStationProtoP\001Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstation'),
  serialized_pb=_b('\n7stellarstation/api/v1/groundstation/groundstation.proto\x12#stellarstation.api.v1.groundstation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'stellarstation/api/v1/radio/radio.proto\x1a%stellarstation/api/v1/transport.proto\"\x8c\x01\n\x10ListPlansRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x11ListPlansResponse\x12\x37\n\x04plan\x18\x01 \x03(\x0b\x32).stellarstation.api.v1.groundstation.Plan\"\xb2\x03\n\x04Plan\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x35\n\x03tle\x18\x02 \x01(\x0b\x32(.stellarstation.api.v1.groundstation.Tle\x12.\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x61os_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\x15\x64ownlink_radio_device\x18\x05 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\x12R\n\x13uplink_radio_device\x18\x06 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\t\"\x87\x01\n\x14UnavailabilityWindow\x12\x11\n\twindow_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9b\x01\n ListUnavailabilityWindowsRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n!ListUnavailabilityWindowsResponse\x12I\n\x06window\x18\x01 \x03(\x0b\x32\x39.stellarstation.api.v1.groundstation.UnavailabilityWindow\"\x99\x01\n\x1e\x41\x64\x64UnavailabilityWindowRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"4\n\x1f\x41\x64\x64UnavailabilityWindowResponse\x12\x11\n\twindow_id\x18\x01 \x01(\t\"6\n!DeleteUnavailabilityWindowRequest\x12\x11\n\twindow_id\x18\x01 \x01(\t\"$\n\"DeleteUnavailabilityWindowResponse\"\xea\x01\n\x1aGroundStationStreamRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12\x12\n\nstream_tag\x18\x02 \x01(\t\x12V\n\x13satellite_telemetry\x18\x03 \x01(\x0b\x32\x37.stellarstation.api.v1.groundstation.SatelliteTelemetryH\x00\x12:\n\x0cstream_event\x18\x04 \x01(\x0b\x32\".stellarstation.api.v1.StreamEventH\x00\x42\t\n\x07Request\"Z\n\x12SatelliteTelemetry\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x33\n\ttelemetry\x18\x02 \x01(\x0b\x32 .stellarstation.api.v1.Telemetry\"\xa5\x01\n\x1bGroundStationStreamResponse\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x13\n\x0bresponse_id\x18\x02 \x01(\t\x12T\n\x12satellite_commands\x18\x03 \x01(\x0b\x32\x36.stellarstation.api.v1.groundstation.SatelliteCommandsH\x00\x42\n\n\x08Response\"$\n\x11SatelliteCommands\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\x0c\x32\xb9\x06\n\x14GroundStationService\x12\xa4\x01\n\x17\x41\x64\x64UnavailabilityWindow\x12\x43.stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest\x1a\x44.stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse\x12\xad\x01\n\x1a\x44\x65leteUnavailabilityWindow\x12\x46.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest\x1aG.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse\x12z\n\tListPlans\x12\x35.stellarstation.api.v1.groundstation.ListPlansRequest\x1a\x36.stellarstation.api.v1.groundstation.ListPlansResponse\x12\xaa\x01\n\x19ListUnavailabilityWindows\x12\x45.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest\x1a\x46.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse\x12\xa0\x01\n\x17OpenGroundStationStream\x12?.stellarstation.api.v1.groundstation.GroundStationStreamRequest\x1a@.stellarstation.api.v1.groundstation.GroundStationStreamResponse(\x01\x30\x01\x42\x81\x01\n\'com.stellarstation.api.v1.groundstationB\x12GroundStationProtoP\x01Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstationb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_transport__pb2.DESCRIPTOR,])




_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.groundstation.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=350,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.groundstation.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.groundstation.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=428,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.groundstation.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.Plan.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.groundstation.Plan.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.Plan.start_time', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.Plan.end_time', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.groundstation.Plan.aos_time', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.groundstation.Plan.los_time', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.downlink_radio_device', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.uplink_radio_device', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=865,
)


_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.groundstation.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.groundstation.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.groundstation.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=904,
)


_UNAVAILABILITYWINDOW = _descriptor.Descriptor(
  name='UnavailabilityWindow',
  full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1042,
)


_LISTUNAVAILABILITYWINDOWSREQUEST = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsRequest',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1200,
)


_LISTUNAVAILABILITYWINDOWSRESPONSE = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsResponse',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse.window', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1312,
)


_ADDUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='AddUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1468,
)


_ADDUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='AddUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1522,
)


_DELETEUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1524,
  serialized_end=1578,
)


_DELETEUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1580,
  serialized_end=1616,
)


_GROUNDSTATIONSTREAMREQUEST = _descriptor.Descriptor(
  name='GroundStationStreamRequest',
  full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_tag', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.stream_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='satellite_telemetry', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.satellite_telemetry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_event', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.stream_event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.Request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1619,
  serialized_end=1853,
)


_SATELLITETELEMETRY = _descriptor.Descriptor(
  name='SatelliteTelemetry',
  full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.telemetry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=1945,
)


_GROUNDSTATIONSTREAMRESPONSE = _descriptor.Descriptor(
  name='GroundStationStreamResponse',
  full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.response_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='satellite_commands', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.satellite_commands', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.Response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1948,
  serialized_end=2113,
)


_SATELLITECOMMANDS = _descriptor.Descriptor(
  name='SatelliteCommands',
  full_name='stellarstation.api.v1.groundstation.SatelliteCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.groundstation.SatelliteCommands.command', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2151,
)

_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PLAN.fields_by_name['tle'].message_type = _TLE
_PLAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['downlink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_PLAN.fields_by_name['uplink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_UNAVAILABILITYWINDOW.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UNAVAILABILITYWINDOW.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSRESPONSE.fields_by_name['window'].message_type = _UNAVAILABILITYWINDOW
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'].message_type = _SATELLITETELEMETRY
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._STREAMEVENT
_GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'])
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'].containing_oneof = _GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request']
_GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'])
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'].containing_oneof = _GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request']
_SATELLITETELEMETRY.fields_by_name['telemetry'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._TELEMETRY
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'].message_type = _SATELLITECOMMANDS
_GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'])
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'].containing_oneof = _GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response']
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['Tle'] = _TLE
DESCRIPTOR.message_types_by_name['UnavailabilityWindow'] = _UNAVAILABILITYWINDOW
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsRequest'] = _LISTUNAVAILABILITYWINDOWSREQUEST
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsResponse'] = _LISTUNAVAILABILITYWINDOWSRESPONSE
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowRequest'] = _ADDUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowResponse'] = _ADDUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowRequest'] = _DELETEUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowResponse'] = _DELETEUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['GroundStationStreamRequest'] = _GROUNDSTATIONSTREAMREQUEST
DESCRIPTOR.message_types_by_name['SatelliteTelemetry'] = _SATELLITETELEMETRY
DESCRIPTOR.message_types_by_name['GroundStationStreamResponse'] = _GROUNDSTATIONSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['SatelliteCommands'] = _SATELLITECOMMANDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Request for the ``ListPlans`` method.
  
  
  Attributes:
      ground_station_id:
          The ID of the ground station to list plans for. The ID can be
          found on the StellarStation Console page for the ground
          station.
      aos_after:
          The start time of the range of plans to list (inclusive). Only
          plans with an Acquisition of Signal (AOS) at or after this
          time will be returned. It is an error for the duration between
          ``aos_after`` and ``aos_before`` to be longer than 31 days.
      aos_before:
          The end time of the range of plans to list (exclusive). Only
          plans with an Acquisition of Signal (AOS) before this time
          will be returned. It is an error for the duration between
          ``aos_after`` and ``aos_before`` to be longer than 31 days.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansRequest)
  ))
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response from the ``ListPlans`` method.
  
  
  Attributes:
      plan:
          The requested list of plans for the ground station.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansResponse)
  ))
_sym_db.RegisterMessage(ListPlansResponse)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A scheduled pass. The plan will be executed on its ground station to
  communicate with its satellite during a time range between AOS and LOS,
  unless explicitly cancelled.
  
  Next ID: 9
  
  
  Attributes:
      plan_id:
          The ID of this plan.
      tle:
          The TLE for the satellite in this plan.
      start_time:
          The start of the time window reserved for the plan.  This
          timestamp does not change over time, and is set to allow
          sufficient time at the start of a plan to allow the ground
          station to prepare for plan execution.
      end_time:
          The end of the time window reserved for the plan.  This
          timestamp does not change over time, and is set to allow
          sufficient time at the end of a plan to allow the ground
          station to perform cleanup tasks after executing the plan.
      aos_time:
          The time of AOS between the ground station and satellite in
          this plan.  This timestamp will never be before ‘start_time’.
          If may change over time (for example, if updated TLE becomes
          available).
      los_time:
          The time of LOS between the ground station and satellite in
          this plan.  This timestamp will never be after ‘end_time’. If
          may change over time (for example, if updated TLE becomes
          available).
      downlink_radio_device:
          Configuration of the radio device used for downlinking from
          the satellite. Ground stations will need to configure
          reception during the plan to match this device.
      uplink_radio_device:
          Configuration of the radio device used for uplinking to the
          satellite. Ground stations will need to configure transmission
          during the plan to match this device.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Plan)
  ))
_sym_db.RegisterMessage(Plan)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), dict(
  DESCRIPTOR = _TLE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Unparsed TLE data for a satellite -
  https://en.wikipedia.org/wiki/Two-line_element_set
  
  
  Attributes:
      line_1:
          The first line of the TLE. Not a title line.
      line_2:
          The second line of the TLE.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Tle)
  ))
_sym_db.RegisterMessage(Tle)

UnavailabilityWindow = _reflection.GeneratedProtocolMessageType('UnavailabilityWindow', (_message.Message,), dict(
  DESCRIPTOR = _UNAVAILABILITYWINDOW,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A time window during which a ground station is unavailable e.g. for
  local maintenance.
  
  
  Attributes:
      window_id:
          The ID of the unavailability window.
      start_time:
          Start time of the unavailabilty window.
      end_time:
          End time of the unavailability window.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.UnavailabilityWindow)
  ))
_sym_db.RegisterMessage(UnavailabilityWindow)

ListUnavailabilityWindowsRequest = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTUNAVAILABILITYWINDOWSREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A request for a list of unavailability windows for the specified ground
  station that fall within the given time range.
  
  
  Attributes:
      ground_station_id:
          ID of the ground station for which to retrieve unavailability
          windows.
      start_time:
          Start time.
      end_time:
          End time.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest)
  ))
_sym_db.RegisterMessage(ListUnavailabilityWindowsRequest)

ListUnavailabilityWindowsResponse = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTUNAVAILABILITYWINDOWSRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response containing unavailability windows for the requested ground
  station.
  
  
  Attributes:
      window:
          A list of unavailability windows, sorted in ascending order of
          the start time.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse)
  ))
_sym_db.RegisterMessage(ListUnavailabilityWindowsResponse)

AddUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDUNAVAILABILITYWINDOWREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A request for adding a new unavailability window for the specified
  ground station.
  
  
  Attributes:
      ground_station_id:
          ID of the ground station to add a new unavailability window.
      start_time:
          Start time of the unavailabilty window.
      end_time:
          End time of the unavailability window.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest)
  ))
_sym_db.RegisterMessage(AddUnavailabilityWindowRequest)

AddUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDUNAVAILABILITYWINDOWRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response from the ‘AddUnavailabilityWindow’ method.
  
  
  Attributes:
      window_id:
          ID of the new window.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse)
  ))
_sym_db.RegisterMessage(AddUnavailabilityWindowResponse)

DeleteUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEUNAVAILABILITYWINDOWREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A request for deleting an existing unavailability window for the
  specified ground station.
  
  
  Attributes:
      window_id:
          ID of the unavailability window to delete.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest)
  ))
_sym_db.RegisterMessage(DeleteUnavailabilityWindowRequest)

DeleteUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEUNAVAILABILITYWINDOWRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response to the request for deleting an existing unavailability
  window.
  
  Currently no payload in the response.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse)
  ))
_sym_db.RegisterMessage(DeleteUnavailabilityWindowResponse)

GroundStationStreamRequest = _reflection.GeneratedProtocolMessageType('GroundStationStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDSTATIONSTREAMREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A payload to send on the ground station stream. The payload does not
  need to be filled on the first request to ``OpenGroundStationStream``.
  
  
  Attributes:
      ground_station_id:
          The ID of the ground station that is opening a stream. The ID
          of a ground station can be found on the StellarStation Console
          page for the ground station.
      stream_tag:
          A tag to identify this stream. This tag is not used
          semantically and is only for logging, monitoring, and
          debugging. This does not need to be set if there will only
          ever be one stream for a particular ``ground_station_id`` open
          at a time. If multiple streams will be open, this should be
          set to identify the stream. Some examples include ‘uplink’,
          ‘downlink’, ‘uhf’, ‘s-band’.
      stream_event:
          An event that occurred while processing the stream. Satellite
          operators will often use these events for debugging and
          monitoring.  -  ``command_sent`` must be returned right after
          completing transmission    of commands received in a
          ``SendSatelliteCommandsResponse``. -
          ``plan_monitoring_event.ground_station_configuration`` must be
          returned once at the beginning of the execution of a plan and
          contains information about the actual configuration of the
          ground    station at the time. -
          ``plan_monitoring_event.ground_station_state`` must be sent
          regularly    throughout the plan and contains real-time
          monitoring of the hardware    of the ground station. -
          ``plan_monitoring_event.ground_station_event`` must be sent
          once at    each of the transitions documented in
          ``PlanLifecycleEvent`` when    executing a plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GroundStationStreamRequest)
  ))
_sym_db.RegisterMessage(GroundStationStreamRequest)

SatelliteTelemetry = _reflection.GeneratedProtocolMessageType('SatelliteTelemetry', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITETELEMETRY,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Telemetry received from a satellite to send to a satellite operator.
  
  
  Attributes:
      plan_id:
          The ID of the plan the telemetry is being sent for.
      telemetry:
          The telemetry being sent.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteTelemetry)
  ))
_sym_db.RegisterMessage(SatelliteTelemetry)

GroundStationStreamResponse = _reflection.GeneratedProtocolMessageType('GroundStationStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDSTATIONSTREAMRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A payload sent on the stream to be processed by the ground station.
  Currently only commands to send to a satellite will be returned to the
  ground station.
  
  
  Attributes:
      plan_id:
          The ID of the plan this response corresponds to. Unfilled if
          this response does not correspond to a plan.
      response_id:
          A unique ID identifying this response. If filled, any
          ``StreamEvent`` generated when handling this
          GroundStationStreamResponse\ ``must have this value copied
          into``\ StreamEvent.request_id`. Currently, this includes  -
          Returning ``CommandSentFromGroundStation`` after completing
          transmission of the commands in a
          ``SendSatelliteCommandsResponse``.
      satellite_commands:
          Commands to send to the satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GroundStationStreamResponse)
  ))
_sym_db.RegisterMessage(GroundStationStreamResponse)

SatelliteCommands = _reflection.GeneratedProtocolMessageType('SatelliteCommands', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITECOMMANDS,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Command to transmit to the satellite.
  
  
  Attributes:
      command:
          The command frames to send to the satellite. All commands must
          be transmitted in sequence immediately. After all commands
          have been transmitted, telemetry receive must be immediately
          enabled again.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteCommands)
  ))
_sym_db.RegisterMessage(SatelliteCommands)


DESCRIPTOR._options = None

_GROUNDSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='GroundStationService',
  full_name='stellarstation.api.v1.groundstation.GroundStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2154,
  serialized_end=2979,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.AddUnavailabilityWindow',
    index=0,
    containing_service=None,
    input_type=_ADDUNAVAILABILITYWINDOWREQUEST,
    output_type=_ADDUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.DeleteUnavailabilityWindow',
    index=1,
    containing_service=None,
    input_type=_DELETEUNAVAILABILITYWINDOWREQUEST,
    output_type=_DELETEUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListPlans',
    index=2,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListUnavailabilityWindows',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListUnavailabilityWindows',
    index=3,
    containing_service=None,
    input_type=_LISTUNAVAILABILITYWINDOWSREQUEST,
    output_type=_LISTUNAVAILABILITYWINDOWSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OpenGroundStationStream',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.OpenGroundStationStream',
    index=4,
    containing_service=None,
    input_type=_GROUNDSTATIONSTREAMREQUEST,
    output_type=_GROUNDSTATIONSTREAMRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUNDSTATIONSERVICE)

DESCRIPTOR.services_by_name['GroundStationService'] = _GROUNDSTATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from stellarstation.api.v1 import stellarstation_pb2 as stellarstation_dot_api_dot_v1_dot_stellarstation__pb2


class StellarStationServiceStub(object):
  """The public API service of StellarStation, a system supporting communication between satellites
  and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
  satellites that the operator does not own or plans they have not reserved.
  Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
  inputs are valid.

  A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
  the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
  satellite pair.

  A plan is a scheduled pass that will be executed to send and receive data between the ground
  station and satellite during the time range.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListPlans = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/ListPlans',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansResponse.FromString,
        )
    self.CancelPlan = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/CancelPlan',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanResponse.FromString,
        )
    self.ListUpcomingAvailablePasses = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/ListUpcomingAvailablePasses',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesResponse.FromString,
        )
    self.OpenSatelliteStream = channel.stream_stream(
        '/stellarstation.api.v1.StellarStationService/OpenSatelliteStream',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.FromString,
        )
    self.ReservePass = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/ReservePass',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassResponse.FromString,
        )
    self.AddTle = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/AddTle',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleResponse.FromString,
        )
    self.GetTle = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/GetTle',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleResponse.FromString,
        )


class StellarStationServiceServicer(object):
  """The public API service of StellarStation, a system supporting communication between satellites
  and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
  satellites that the operator does not own or plans they have not reserved.
  Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
  inputs are valid.

  A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
  the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
  satellite pair.

  A plan is a scheduled pass that will be executed to send and receive data between the ground
  station and satellite during the time range.
  """

  def ListPlans(self, request, context):
    """Lists the plans for a particular satellite.

    The request will be closed with an `INVALID_ARGUMENT` status if `satellite_id`,
    `aos_after`, or `aos_before` are missing, or the duration between the two times is longer than
    31 days.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CancelPlan(self, request, context):
    """Cancel a previously reserved upcoming plan. Cancelling the plan will cause it to not be
    executed. This action cannot be undone, but it is still possible to reserve the corresponding
    pass again by calling `ListUpcomingAvailablePasses` and `ReservePass` as usual - this will
    cause a new plan to be reserved. The plan cannot be cancelled less than ten minutes before
    AOS.

    Canceling a plan may incur a charge based on the time left to AOS. See our cancellation policy
    for details.

    If the plan is not found, the request will return a `NOT_FOUND` error.

    If the plan has already been canceled or is less than ten minutes away from its AOS, the
    request will return a `FAILED_PRECONDITION` error.

    If the plan is ongoing or has already finished executing, the request will return a
    `OUT_OF_RANGE` error.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListUpcomingAvailablePasses(self, request, context):
    """Lists upcoming passes for a satellite. Passes that can be scheduled for the satellite with an
    Acquisition of Signal (AOS) within 14 days from now will be returned. This method does not
    reserve passes in any way - it is possible for a pass that is returned by this method to be
    unschedulable when actually trying to schedule because a conflict appeared during that time.

    If the satellite is not found or the client is not authorized for it, the request will return
    a `NOT_FOUND` error.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OpenSatelliteStream(self, request_iterator, context):
    """Open a stream to a satellite. The returned stream is bi-directional - it can be used by the
    client to send commands to the satellite and data received from the satellite will be returned
    as it is made available. All telemetry received from the satellite on reserved passes along
    with associated events from this point on will be returned as soon as this method is called. If
    `SatelliteStreamRequest.stream_id` is specified, any messages that have been buffered for the
    stream will be returned as well.

    The first `SatelliteStreamRequest` sent on the stream is used for configuring the stream.
    Unless otherwise specified, all configuration is taken from the first request and configuration
    values in subsequent requests will be ignored.

    The stream can be left open for any amount of time and telemetry will be received as available
    and returned. When the client is done with the stream, it should close it successfully. If the
    stream is cancelled with an unexpected error at any point, telemetry received before the next
    call to `OpenSatelliteStream` to resume the stream will be buffered up to 1 minute, and if no
    call to `OpenSatelliteStream` is made with `stream_id` specified to resume the stream, it will
    expire in 10 minutes and a call to `OpenSatelliteStream` with that `stream_id` will be closed
    with a `ABORTED` error.

    If the satellite is not found or the client is not authorized for it, the stream will be closed
    with a `NOT_FOUND` error.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ReservePass(self, request, context):
    """Reserves a pass for later execution as a plan. The pass must be specified by a
    `reservation_token` returned in another method like `ListUpcomingAvailablePasses` and its
    `aos_time` must be at least one hour in the future.

    If the `reservation_token` is invalid, the request will return an `INVALID_ARGUMENT` error.

    If the requested pass cannot be scheduled due to a conflict with existing plans or other
    scheduling constraints, the request will return a `FAILED_PRECONDITION` error. This includes
    if the pass `aos_time` is less than one hour in the future.

    Note that the reservation_token may have become unreservable since it was fetched. If that's
    the case, the call to `ReservePass` will fail with a 'FAILED_PRECONDITION' error and
    `ListUpcomingAvailablePasses` should be called again to get a fresh list of reservable passes.
    The pass must be scheduled at least one hour in advance of `aos_time` or it will be rejected.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddTle(self, request, context):
    """Adds TLE for a satellite.

    The TLE will be used for satellite orbit calculation until it is superseded by a TLE with a
    more recent epoch. This happens automatically if StellarStation pulls new TLE data from
    external sources, or manually through this API etc.

    An 'INVALID_ARGUMENT' error will be returned in the following conditions:
    - the TLE cannot be parsed
    - the TLE norad ID does not correspond to the requested satellite.

    If the satellite is not found or the client is not authorized for it, the request will return
    a `NOT_FOUND` error.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTle(self, request, context):
    """Gets the TLE for a satellite.

    The returned TLE will be the one that has the latest epoch known to StellarStation, and is
    used when calculating satellite orbits.

    If the satellite is not found or the client is not authorized for it, the request will return
    a `NOT_FOUND` error.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StellarStationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListPlans': grpc.unary_unary_rpc_method_handler(
          servicer.ListPlans,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansResponse.SerializeToString,
      ),
      'CancelPlan': grpc.unary_unary_rpc_method_handler(
          servicer.CancelPlan,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanResponse.SerializeToString,
      ),
      'ListUpcomingAvailablePasses': grpc.unary_unary_rpc_method_handler(
          servicer.ListUpcomingAvailablePasses,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesResponse.SerializeToString,
      ),
      'OpenSatelliteStream': grpc.stream_stream_rpc_method_handler(
          servicer.OpenSatelliteStream,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.SerializeToString,
      ),
      'ReservePass': grpc.unary_unary_rpc_method_handler(
          servicer.ReservePass,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassResponse.SerializeToString,
      ),
      'AddTle': grpc.unary_unary_rpc_method_handler(
          servicer.AddTle,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleResponse.SerializeToString,
      ),
      'GetTle': grpc.unary_unary_rpc_method_handler(
          servicer.GetTle,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'stellarstation.api.v1.StellarStationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/antenna/antenna.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/antenna/antenna.proto',
  package='stellarstation.api.v1.antenna',
  syntax='proto3',
  serialized_options=_b('\n!com.stellarstation.api.v1.antennaB\014AntennaProtoP\001Z:github.com/infostellarinc/go-stellarstation/api/v1/antenna'),
  serialized_pb=_b('\n+stellarstation/api/v1/antenna/antenna.proto\x12\x1dstellarstation.api.v1.antenna\"o\n\x14\x41ntennaConfiguration\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x17\n\x0f\x61ltitude_meters\x18\x03 \x01(\x01\x12\x19\n\x11\x62\x65\x61mwidth_degrees\x18\x04 \x01(\x01*G\n\x13\x41ntennaPolarization\x12\x0e\n\nHORIZONTAL\x10\x00\x12\x0c\n\x08VERTICAL\x10\x01\x12\x08\n\x04LHCP\x10\x02\x12\x08\n\x04RHCP\x10\x03\x42o\n!com.stellarstation.api.v1.antennaB\x0c\x41ntennaProtoP\x01Z:github.com/infostellarinc/go-stellarstation/api/v1/antennab\x06proto3')
)

_ANTENNAPOLARIZATION = _descriptor.EnumDescriptor(
  name='AntennaPolarization',
  full_name='stellarstation.api.v1.antenna.AntennaPolarization',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTICAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LHCP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RHCP', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=191,
  serialized_end=262,
)
_sym_db.RegisterEnumDescriptor(_ANTENNAPOLARIZATION)

AntennaPolarization = enum_type_wrapper.EnumTypeWrapper(_ANTENNAPOLARIZATION)
HORIZONTAL = 0
VERTICAL = 1
LHCP = 2
RHCP = 3



_ANTENNACONFIGURATION = _descriptor.Descriptor(
  name='AntennaConfiguration',
  full_name='stellarstation.api.v1.antenna.AntennaConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude_meters', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.altitude_meters', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beamwidth_degrees', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.beamwidth_degrees', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=189,
)

DESCRIPTOR.message_types_by_name['AntennaConfiguration'] = _ANTENNACONFIGURATION
DESCRIPTOR.enum_types_by_name['AntennaPolarization'] = _ANTENNAPOLARIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AntennaConfiguration = _reflection.GeneratedProtocolMessageType('AntennaConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _ANTENNACONFIGURATION,
  __module__ = 'stellarstation.api.v1.antenna.antenna_pb2'
  ,
  __doc__ = """The static configuration of an antenna. These are the physical
  parameters of the antenna.
  
  
  Attributes:
      latitude:
          The latitude of the antenna, in degrees.
      longitude:
          The longitude of the antenna, in degrees.
      altitude_meters:
          The altitude of the antenna above mean sea level, in meters.
      beamwidth_degrees:
          The beamwidth, in degrees.
          https://en.wikipedia.org/wiki/Beamwidth
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.antenna.AntennaConfiguration)
  ))
_sym_db.RegisterMessage(AntennaConfiguration)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
